powered by
A data set with the awards and nominations of the Academy Awards, popularly known as the Oscars, each Pixar film has won.
academy
A data frame with 72 rows and 3 variables:
name of film
name of award
status of award
This data set is put into a tidy format, where each row is a film-award data point.
Some films did not qualify for categories so there is no data for that film.
# NOT RUN { academy # }
Run the code above in your browser using DataLab