Learn R Programming

pixarfilms (version 0.2.1)

genres: Genres describing Pixar films

Description

A data set with the different genre categories for each Pixar film.

Usage

genres

Arguments

Format

A data frame with 128 rows and 2 variables:

film

name of film

genre

genre film is categorized into

Details

This data set is put into a tidy format, where each row is a film-genre data point. Each film can have multiple genres. For example, Toy Story is categorized into five genres.

Examples

Run this code
# NOT RUN {
genres
# }

Run the code above in your browser using DataLab