Learn R Programming

pixarfilms (version 0.2.1)

pixar_people: People behind Pixar

Description

A data set containing the main people involved in each Pixar film.

Usage

pixar_people

Arguments

Format

A data frame with 228 rows and 3 variables:

film

name of film

role_type

one of five roles: Director, Musician, Producer, Screenwriter, Storywriter

name

individual's name

Details

This data set is put into a tidy format, where each row is a film-role data point. Each film can have multiple individuals per role. For example, Toy Story has four screenwriters.

Examples

Run this code
# NOT RUN {
pixar_people
# }

Run the code above in your browser using DataLab