Learn R Programming

pixarfilms (version 0.2.1)

public_response: Critical and public response

Description

A data set with scores of critical and public response.

Usage

public_response

Arguments

Format

A data frame with 23 rows and 5 variables:

film

name of film

rotten_tomatoes

score from the American review-aggregation website Rotten Tomatoes; scored out of 100

metacritic

score from Metacritic where scores are weighted average of reviews; scored out of 100

cinema_score

score from market research firm CinemaScore; scored by grades A, B, C, D, and F

critics_choice

score from Critics' Choice Movie Awards presented by the American-Canadian Critics Choice Association (CCA); scored out of 100

Examples

Run this code
# NOT RUN {
public_response
# }

Run the code above in your browser using DataLab