powered by
A data set with scores of critical and public response.
public_response
A data frame with 23 rows and 5 variables:
name of film
score from the American review-aggregation website Rotten Tomatoes; scored out of 100
score from Metacritic where scores are weighted average of reviews; scored out of 100
score from market research firm CinemaScore; scored by grades A, B, C, D, and F
score from Critics' Choice Movie Awards presented by the American-Canadian Critics Choice Association (CCA); scored out of 100
# NOT RUN { public_response # }
Run the code above in your browser using DataLab